@@ -1,4 +1,5 @@
 from django.db import models
+from cms.models import CMSPlugin
 
 from giant_plugins.utils import RichTextField
 from mixins.models import TimestampMixin
@@ -68,3 +69,16 @@ class Category(models.Model):
 
     def __str__(self):
         return self.name
+
+
+class FAQBlock(CMSPlugin):
+    """
+    CMS plugin model which holds a select number of FAQs
+    """
+    faqs = models.ManyToManyField(to="giant_faqs.FAQ")
+    
+    def __str__(self):
+        return f"FAQ block {self.pk}"
+
+    def copy_relations(self, oldinstance):
+        self.faqs.set(oldinstance.faqs.all())
